@@ -1,5 +1,5 @@
 from ext import EXT_CONTEXT
-from ext.utils.db_utils import object_to_dict
+from ext.utils.db_utils import object_to_dict, query2dict
 
 from model1.goods.model import Goods
 
@@ -16,7 +16,7 @@ class GoodsDao(object):
         with EXT_CONTEXT["db"].session_maker() as session:
             new_user = Goods(name=params.get("name"))
             session.add(new_user)
-            return object_to_dict(new_user)
+            return query2dict(new_user)
 
 
     def find(self, **params):
@@ -31,7 +31,7 @@ class GoodsDao(object):
             if role:
                 print('type:', type(role))
                 print('name:', role.name)
-                return object_to_dict(role)
+                return query2dict(role)
             else:
                 return None
 
@@ -48,6 +48,6 @@ class GoodsDao(object):
             list = session.query(Goods).filter(Goods.id == params.get("id")).all()
             if list:
                 print('type:', type(list))
-                return object_to_dict(list)
+                return query2dict(list)
             else:
                 return None
\ No newline at end of file
