@@ -1,4 +1,5 @@
-from model1.common_utils import resp_result
+from ext.utils.resp_utils import resp_result
+
 from model1.goods.dao import GoodsDao
 
 
@@ -18,7 +19,7 @@ class Service(object):
                 print("find params===>key={0},value={1}".format(i, params[i]))
 
         user = GoodsDao()
-        return resp_result(data=user.find(**params))
+        return resp_result(data=user.page(**params))
 
 
     def _api_post(self, **params):
